@@ -1,10 +1,10 @@
 library(lingtypology)
 context("Tests for area.lang function")
 
-df <- data.frame(my_langs = c("Korean", "Polish"))
+df <- data.frame(my_langs = c("Korean", "Polish"), stringsAsFactors = FALSE)
 
 test_that("area.lang", {
     expect_equal(area.lang("Adyghe"), c(Adyghe = "Eurasia"))
     expect_equal(area.lang(c("Adyghe", "Aduge")), c(Adyghe = "Eurasia", Aduge = "Africa"))
-    expect_equal(area.lang(df), c("Eurasia", "Eurasia"))
+    expect_equal(area.lang(df), c(my_langs1 = "Eurasia", my_langs2 = "Eurasia"))
 })
